/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import org.fortiss.tooling.base.model.layout.EOrientation;
import org.fortiss.tooling.base.model.layout.ILayoutData;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.model.layout.OffsetOrientation;
import org.fortiss.tooling.base.model.layout.Orientation;

/**
 * Utility class for {@link OffsetOrientation} layout data.
 * 
 * @author wandinger
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 557B7E385BC75BF05E76F4B4D292C318
 */
public final class OffsetOrientationUtils {

	/**
	 * Returns a {@link OffsetOrientation} layout data object with the given
	 * key.
	 */
	public static OffsetOrientation getOffsetOrientation(
			ILayoutedModelElement lobject, String key) {
		for (ILayoutData ld : lobject.getLayoutDataList()) {
			if (ld.getKey().equals(key) || ld instanceof Orientation) {
				return (OffsetOrientation) ld;
			}
		}
		return null;
	}

	/** Sets a {@link Orientation} layout data object with the given key. */
	public static void setOffsetOrientation(ILayoutedModelElement lobject,
			String key, int offset, EOrientation orientation) {
		Orientation old = getOffsetOrientation(lobject, key);
		if (old != null) {
			lobject.getLayoutDataList().remove(old);
		}

		Orientation o = LayoutModelElementFactory.createOffsetOrientation(
				offset, orientation, key);
		lobject.getLayoutDataList().add(o);
	}
}
